"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatNumber = exports.formatBytes = void 0;

var _d3Format = require("d3-format");

/**
 * @param {Number} number
 * @param {Boolean} [includeDecimals]
 * @return {String}
 */
var formatBytes = function formatBytes(number, includeDecimals) {
  return formatNumber(number, true, includeDecimals ? 2 : 0) // Add space between value and SI unit
  .replace(/([a-zA-Z]?)$/, ' $1') + 'B';
};
/**
 * @param {Number} number
 * @param {Boolean} [useSI]
 * @param {Number} [significantDecimals]
 * @param {Boolean} [trimInsignificantZeros]
 * @return {String}
 */


exports.formatBytes = formatBytes;

var formatNumber = function formatNumber(number) {
  var useSI = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var significantDecimals = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;
  var trimInsignificantZeros = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
  var val = number;
  var suffix = ''; // Don't use SI units for sub-1 numbers (milli, micro, etc)

  if (useSI && number >= 1) {
    var siMatch = /^([^a-zA-Z]*)([a-zA-Z]?$)/.exec((0, _d3Format.format)('s')(number)); // split value from SI unit

    val = +siMatch[1];
    suffix = siMatch[2] || '';
  }

  return (0, _d3Format.format)(",.".concat(significantDecimals).concat(trimInsignificantZeros ? '~' : '', "f"))(val) + suffix;
};

exports.formatNumber = formatNumber;