import { format as d3Format } from 'd3-format';

/**
 * @param {Number} number
 * @param {Boolean} [includeDecimals]
 * @return {String}
 */
export const formatBytes = (number, includeDecimals) => {
  return (
    formatNumber(number, true, includeDecimals ? 2 : 0)
      // Add space between value and SI unit
      .replace(/([a-zA-Z]?)$/, ' $1') + 'B'
  );
};

/**
 * @param {Number} number
 * @param {Boolean} [useSI]
 * @param {Number} [significantDecimals]
 * @param {Boolean} [trimInsignificantZeros]
 * @return {String}
 */
export const formatNumber = (
  number,
  useSI = false,
  significantDecimals = 2,
  trimInsignificantZeros = true
) => {
  let val = number;
  let suffix = '';

  // Don't use SI units for sub-1 numbers (milli, micro, etc)
  if (useSI && number >= 1) {
    const siMatch = /^([^a-zA-Z]*)([a-zA-Z]?$)/.exec(d3Format('s')(number)); // split value from SI unit
    val = +siMatch[1];
    suffix = siMatch[2] || '';
  }

  return (
    d3Format(`,.${significantDecimals}${trimInsignificantZeros ? '~' : ''}f`)(
      val
    ) + suffix
  );
};
